@@ -219,7 +219,7 @@ function TimePlot() {
             }
             var label = list_entry.append("label").attr("for", self.id + parameter_type);
             label.append("span"); // placeholder
-            label.append("strong").text(parameter_type);
+            label.append("strong").text(parameter_type).style("color", roy.parameter_color(parameter_type));
         });
     };
 
@@ -396,7 +396,7 @@ function Histogram() {
             }
             var label = list_entry.append("label").attr("for", self.id + parameter_type);
             label.append("span"); // placeholder
-            label.append("strong").text(parameter_type);
+            label.append("strong").text(parameter_type).style("color", roy.parameter_color(parameter_type));
         });
     };
 
@@ -450,7 +450,7 @@ function Histogram() {
 
     this.redraw = function() {
         this.fetch_data();
-        this.map = self.data.map(function(i) { return i.value; });
+        this.map = self.data.map(function(i) { return parseFloat(i.value); });
         this.histogram = d3.layout.histogram().bins(this.nbins)(this.map);
         this.draw_axes();
         this.draw_bars();
